==> mineral-3.0.0.tar.gz: lib/core/api.dart <==
/// The api is the Map of all the classes, enumerations of the framework
library api;

export '../src/api/activity.dart' show Activity;
export '../src/api/application.dart' show Application;
export '../src/api/channels/category_channel.dart' show CategoryChannel;
export '../src/api/channels/forum_channel.dart' show ForumChannel;
export '../src/api/channels/guild_channel.dart' show GuildChannel;
export '../src/api/channels/partial_channel.dart' show PartialChannel, ChannelType;
export '../src/api/channels/partial_text_channel.dart' show PartialTextChannel;
export '../src/api/channels/text_based_channel.dart' show TextBasedChannel;
export '../src/api/channels/text_channel.dart' show TextChannel;
export '../src/api/channels/thread_channel.dart' show ThreadChannel;
export '../src/api/channels/voice_channel.dart' show VoiceChannel;
export '../src/api/channels/dm_channel.dart' show DmChannel;
export '../src/api/client/client_presence.dart' show ClientPresence, GamePresence;
export '../src/api/client/mineral_client.dart' show MineralClient, ClientActivity, ClientStatus;
export '../src/api/color.dart' show Color;
export '../src/api/emoji.dart' show Emoji;
export '../src/api/guilds/guild.dart' show Guild;
export '../src/api/guilds/guild_member.dart' show GuildMember;
export '../src/api/guilds/guild_preview.dart' show GuildPreview;
export '../src/api/guilds/guild_scheduled_event.dart' show ScheduledEventStatus, ScheduledEventEntityType, GuildScheduledEvent, ScheduledEventUser;
export '../src/api/image_formater.dart' show ImageFormater;
export '../src/api/interactions/button_interaction.dart' show ButtonInteraction;
export '../src/api/interactions/command_interaction.dart' show CommandInteraction;
export '../src/api/interactions/global_command_interaction.dart' show GlobalCommandInteraction;
export '../src/api/interactions/guild_command_interaction.dart' show GuildCommandInteraction;
export '../src/api/interactions/context_message_interaction.dart' show ContextMessageInteraction;
export '../src/api/interactions/context_user_interaction.dart' show ContextUserInteraction;
export '../src/api/interactions/interaction.dart' show Interaction;
export '../src/api/interactions/modal_interaction.dart' show ModalInteraction;
export '../src/api/interactions/select_menu_interaction.dart' show SelectMenuInteraction;
export '../src/api/managers/member_role_manager.dart' show MemberRoleManager;
export '../src/api/managers/voice_manager.dart' show VoiceManager;
export '../src/api/managers/message_manager.dart' show MessageManager, BulkDeleteBuilder;
export '../src/api/messages/message.dart' show Message;
export '../src/api/messages/dm_message.dart' show DmMessage;
export '../src/api/moderation_rule.dart' show ModerationEventType, ModerationTriggerType, ModerationPresetType, ModerationActionType, ModerationTriggerMetadata, ModerationActionMetadata, ModerationAction, ModerationRule;
export '../src/api/permission_overwrite.dart' show PermissionOverwrite, PermissionOverwriteType;
export '../src/api/role.dart' show Role;
export '../src/api/status.dart' show Status, StatusType;
export '../src/api/users/user.dart' show User;
export '../src/api/utils.dart';
export '../src/api/webhook.dart' show Webhook;
export '../src/internal/services/intent_service.dart' show Intent;
export '../src/api/users/premium_type.dart' show PremiumType;
export '../src/api/users/user_decoration.dart' show UserDecoration;
export '../src/api/users/user_flags/user_flag_contract.dart' show UserFlagContract;

typedef Snowflake = String;

==> mineral-3.1.0.tar.gz: lib/core/api.dart <==
/// The api is the Map of all the classes, enumerations of the framework
library api;

export '../src/api/activity.dart' show Activity;
export '../src/api/application.dart' show Application;
export '../src/api/channels/category_channel.dart' show CategoryChannel;
export '../src/api/channels/forum_channel.dart' show ForumChannel;
export '../src/api/channels/guild_channel.dart' show GuildChannel;
export '../src/api/channels/partial_channel.dart' show PartialChannel, ChannelType;
export '../src/api/channels/partial_text_channel.dart' show PartialTextChannel;
export '../src/api/channels/text_based_channel.dart' show TextBasedChannel;
export '../src/api/channels/text_channel.dart' show TextChannel;
export '../src/api/channels/thread_channel.dart' show ThreadChannel;
export '../src/api/channels/voice_channel.dart' show VoiceChannel;
export '../src/api/channels/dm_channel.dart' show DmChannel;
export '../src/api/client/client_presence.dart' show ClientPresence, GamePresence;
export '../src/api/client/mineral_client.dart' show MineralClient, ClientActivity, ClientStatus;
export '../src/api/color.dart' show Color;
export '../src/api/emoji.dart' show Emoji;
export '../src/api/guilds/guild.dart' show Guild;
export '../src/api/guilds/guild_member.dart' show GuildMember;
export '../src/api/guilds/guild_preview.dart' show GuildPreview;
export '../src/api/guilds/guild_scheduled_event.dart' show ScheduledEventStatus, ScheduledEventEntityType, GuildScheduledEvent, ScheduledEventUser;
export '../src/api/image_formater.dart' show ImageFormater;
export '../src/api/interactions/button_interaction.dart' show ButtonInteraction;
export '../src/api/interactions/command_interaction.dart' show CommandInteraction;
export '../src/api/interactions/global_command_interaction.dart' show GlobalCommandInteraction;
export '../src/api/interactions/guild_command_interaction.dart' show GuildCommandInteraction;
export '../src/api/interactions/context_message_interaction.dart' show ContextMessageInteraction;
export '../src/api/interactions/context_user_interaction.dart' show ContextUserInteraction;
export '../src/api/interactions/interaction.dart' show Interaction;
export '../src/api/interactions/modal_interaction.dart' show ModalInteraction;
export '../src/api/interactions/menus/dynamic_menu_interaction.dart' show DynamicMenuInteraction;
export '../src/api/interactions/menus/user_menu_interaction.dart' show UserMenuInteraction;
export '../src/api/managers/member_role_manager.dart' show MemberRoleManager;
export '../src/api/managers/voice_manager.dart' show VoiceManager;
export '../src/api/managers/message_manager.dart' show MessageManager, BulkDeleteBuilder;
export '../src/api/messages/message.dart' show Message;
export '../src/api/messages/dm_message.dart' show DmMessage;
export '../src/api/moderation_rule.dart' show ModerationEventType, ModerationTriggerType, ModerationPresetType, ModerationActionType, ModerationTriggerMetadata, ModerationActionMetadata, ModerationAction, ModerationRule;
export '../src/api/permission_overwrite.dart' show PermissionOverwrite, PermissionOverwriteType;
export '../src/api/role.dart' show Role;
export '../src/api/status.dart' show Status, StatusType;
export '../src/api/users/user.dart' show User;
export '../src/api/utils.dart';
export '../src/api/webhook.dart' show Webhook;
export '../src/internal/services/intent_service.dart' show Intent;
export '../src/api/users/premium_type.dart' show PremiumType;
export '../src/api/users/user_decoration.dart' show UserDecoration;
export '../src/api/users/user_flags/user_flag_contract.dart' show UserFlagContract;
export '../src/api/client/client_scope.dart' show ClientScope;
export '../src/api/client/client_permission.dart' show ClientPermission;
export '../src/api/guilds/activities/activity_type.dart' show ActivityType;

typedef Snowflake = String;
